@@ -142,7 +142,8 @@ class TaskManager(ResultManager):
             return self.model(task_id=task_id)
 
     @transaction_retry(max_retries=2)
-    def store_result(self, task_id, result, status, traceback=None):
+    def store_result(self, task_id, result, status, traceback=None,
+            children=None):
         """Store the result and status of a task.
 
         :param task_id: task id
@@ -157,6 +158,9 @@ class TaskManager(ResultManager):
         :keyword traceback: The traceback at the point of exception (if the
             task failed).
 
+        :keyword children: List of serialized results of subtasks
+            of this task.
+
         :keyword exception_retry_count: How many times to retry by
             transaction rollback on exception. This could theoretically
             happen in a race condition if another worker is trying to
@@ -166,7 +170,8 @@ class TaskManager(ResultManager):
         return self.update_or_create(task_id=task_id,
                                      defaults={"status": status,
                                                "result": result,
-                                               "traceback": traceback})
+                                               "traceback": traceback,
+                                               "meta": {"children": children}})
 
     def warn_if_repeatable_read(self):
         if "mysql" in self.current_engine().lower():
